bayespy.inference.vmp.nodes.gaussian.GaussianGammaDistribution.compute_cgf_from_parents
=======================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaDistribution.compute_cgf_from_parents